@@ -152,6 +152,7 @@ class OpenApiWrapper:
             types.UnionType: self._get_union_description,
             list: self._get_list_description,
             dict: self._get_dict_description,
+            set: self._get_set_description,
         }
         self.primitive_type_to_description: dict[type, dict] = {
             bool: {"type": "boolean"},  # MUST be before int
@@ -206,7 +207,7 @@ class OpenApiWrapper:
         if request_body_datum := self._get_operation_request_body(endpoint.request_body):
             operation_dict["requestBody"] = request_body_datum
 
-        spec.path(endpoint.path, operations={endpoint.method: operation_dict})
+        spec.path(endpoint.path, operations={endpoint.method.lower(): operation_dict})
 
     def _get_operation_parameters(self, parameters: list[Parameter]) -> list[dict[str, Any]]:
         result: list[dict[str, Any]] = []
@@ -245,6 +246,13 @@ class OpenApiWrapper:
         else:
             return {"type": "array"}
 
+    def _get_set_description(self, type_args: tuple[type | UnionType] | None) -> dict:
+        description = {"type": "array", 'uniqueItems': True}
+        if type_args:
+            assert type_args and len(type_args) == 1, f'bad set element type: {type_args}'
+            description |= {"items": self._get_schema_description(type_args[0])}
+        return description
+
     def _get_dict_description(self, type_args: tuple[type | UnionType] | None) -> dict:
         if type_args:
             assert len(type_args) == 2, f'bad dict item type: {type_args}'
